If labels are assigned to the "label" attributes of the data frame
columns, the labels function will extract those labels. The
function will return the labels in a named list, where the names
correspond to the name of the column that the label was assigned to.
If a column does not have a label attribute assigned, that column
will not be included in the list.
When used on the receiving side of an assignment, the function will assign
labels to a data frame. The labels should be in a named list, where
each name corresponds to the data frame column to assign the label to.
Finally, if you wish to clear out the label attributes, assign
a NULL value to the labels function.